@@ -6,7 +6,7 @@ Copyright (c) 2013, Wladston Viana.
 """
 
 __author__ = 'Wladston Viana'
-__version__ = '0.1.9'
+__version__ = '0.1.10'
 __license__ = 'MIT'
 
 # Python.
@@ -310,7 +310,7 @@ class Document(object, metaclass=ModelType):
     documents.
     '''
 
-    def __init__(self, data=None, son=None):
+    def __init__(self, data=None, son=None, **kwargs):
         self._data = {}
         validate_exempt = []
 
